CellHighlightConfig class

Configuration for cell highlighting (collaborative editing style) Used to highlight cells with colored borders when multiple users are editing

Constructors

CellHighlightConfig({bool enabled = false, Color? color, String? userId, String? userName})
const
CellHighlightConfig.fromJson(Map<String, dynamic> json)
factory

Properties

color Color?
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String?
final
userName String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited