ColumnConfig class

Configuration for a single table column Maps from Tabulator-compatible JSON column definitions

Annotations

Constructors

ColumnConfig({required String field, required String title, String columnType = 'stringColumn', bool headerSort = true, bool resizable = true, double width = 100.0, String hozAlign = 'left', String? sorter, bool headerWordWrap = true, FormatterParams? formatterParams, String? headerFilter, String? headerFilterPlaceholder, String? parentTitle, List<ColumnConfig>? columns, CellBuilder? cellBuilder})
const
ColumnConfig.fromJson(Map<String, dynamic> json)
Parse from visualResponse JSON
factory

Properties

cellBuilder CellBuilder?
final
columns List<ColumnConfig>?
final
columnType String
final
field String
final
formatterParams FormatterParams?
final
hashCode int
The hash code for this object.
no setterinherited
hasHeaderFilter bool
Check if this column has a header filter input
no setter
hasNestedColumns bool
Check if this column has nested columns (two-level header)
no setter
headerFilter String?
final
headerFilterPlaceholder String?
final
headerSort bool
final
headerWordWrap bool
final
hozAlign String
final
isChart bool
Check if this is a chart column
no setter
isNumeric bool
Check if this is a numeric column
no setter
parentTitle String?
final
resizable bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sorter String?
final
title String
final
width double
final

Methods

copyWith({String? field, String? title, String? columnType, bool? headerSort, bool? resizable, double? width, String? hozAlign, String? sorter, bool? headerWordWrap, FormatterParams? formatterParams, String? headerFilter, String? headerFilterPlaceholder, String? parentTitle, List<ColumnConfig>? columns, CellBuilder? cellBuilder}) ColumnConfig
Copy with updated values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited