FormattingBasedOn class

"Based on" configuration for conditional formatting

Annotations

Constructors

FormattingBasedOn({required String field, SolidFormatting? solid, GradientFormatting? gradient})
const
FormattingBasedOn.fromJson(Map<String, dynamic> json)
factory

Properties

field String
final
gradient GradientFormatting?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
solid SolidFormatting?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited