NumberFormatValues class

Number formatting values (comma separation, decimals, currency)

Annotations

Constructors

NumberFormatValues({bool commaSperated = false, int decimalPoint = 0, bool currency = false})
const
NumberFormatValues.fromJson(Map<String, dynamic> json)
factory

Properties

commaSperated bool
final
currency bool
final
decimalPoint int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

formatNumber(num value) String
Format a numeric value according to these rules
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited