SolidFormattingSet class

A single range in multi-range solid formatting

Annotations

Constructors

SolidFormattingSet({required double lowerThreshold, required double higherThreshold, required String color})
const
SolidFormattingSet.fromJson(Map<String, dynamic> json)
factory

Properties

color String
final
hashCode int
The hash code for this object.
no setterinherited
higherThreshold double
final
lowerThreshold double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited