ProcessedTableData class

Represents processed table data (totals separated from regular rows)

Annotations

Constructors

ProcessedTableData({required List<Map<String, dynamic>> totalRows, required List<Map<String, dynamic>> regularRows})
const

Properties

allRows List<Map<String, dynamic>>
no setter
hashCode int
The hash code for this object.
no setterinherited
regularRows List<Map<String, dynamic>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalRows List<Map<String, dynamic>>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited