TreeRow class

Represents a row in tree data with hierarchy information

Annotations

Constructors

TreeRow({required Map<String, dynamic> data, required int depth, required bool hasChildren, required String id})
const

Properties

children List<Map<String, dynamic>>
no setter
data Map<String, dynamic>
final
depth int
final
hasChildren bool
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited