menu
medha_boards_table package
documentation
features/highlighting/highlight_manager.dart
features/highlighting/highlight_manager.dart
dark_mode
light_mode
features/highlighting/highlight_manager
library
Classes
HighlightManager
Manages cell highlighting and group border detection Detects groups of adjacent cells with same highlight color and calculates which borders should be thick (group edges only)
medha_boards_table package
documentation
features/highlighting/highlight_manager.dart
medha_boards_table
package
Libraries
adapters/horizontal_table_adapter
config/cell_highlight_config
config/column_config
config/formatter_config
config/table_config
controller/table_controller
controller/table_state
features/filtering/filter_manager
features/formatting/conditional_formatter
features/highlighting/highlight_manager
features/sorting/sort_manager
features/tree/tree_manager
medha_boards_table
models/column_group
models/trend_data
render/body/data_cell
render/body/text_cell
render/body/tree_cell
render/header/header_cell
render/header/resize_handle
render/table_widget
highlight_manager library