TreeManager class

Manages tree data operations (expand/collapse, flattening)

Constructors

TreeManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

flattenTree({required List<Map<String, dynamic>> rows, required Set<String> expandedIds, int depth = 0, String parentId = ''}) List<TreeRow>
Flatten tree data into visible rows based on expanded state Only includes rows whose parents are expanded
getAllExpandableIds(List<Map<String, dynamic>> rows, {String parentId = ''}) Set<String>
Get all expandable row IDs (rows with children)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited