TrendData class

Data model for chart/trend values

Annotations

Constructors

TrendData({required List<String> labels, required List<double> values})
const
TrendData.fromRaw(dynamic raw)
Parse from row data (array of numbers or [labels, values] format)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isPositiveTrend bool
Check if trend is positive
no setter
isValid bool
Validation
no setter
labels List<String>
final
maxValue double
no setter
minValue double
Get min/max values
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trendPercentage double
Calculate trend percentage (first to last value)
no setter
values List<double>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited