HeaderCell class
Header cell widget - displays column header with sorting, filtering, and resizing
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- HeaderCell
Constructors
- HeaderCell({Key? key, required String title, String? parentTitle, required double width, bool isSortable = false, bool isResizable = false, bool hasFilter = false, String? filterPlaceholder, String? filterValue, TextEditingController? filterController, SortIndicator? sortIndicator, VoidCallback? onTap, void onResize(double delta)?, void onFilterChanged(String value)?, required Color backgroundColor, required Color textColor, required Color borderColor, bool showFilterRow = false, bool hasColumnGroups = false})
-
const
Properties
- backgroundColor → Color
-
final
- borderColor → Color
-
final
- filterController → TextEditingController?
-
final
- filterPlaceholder → String?
-
final
- filterValue → String?
-
final
- hasColumnGroups → bool
-
final
- hasFilter → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isResizable → bool
-
final
- isSortable → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onFilterChanged → void Function(String value)?
-
final
- onResize → void Function(double delta)?
-
final
- onTap → VoidCallback?
-
final
- parentTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showFilterRow → bool
-
final
- sortIndicator → SortIndicator?
-
final
- textColor → Color
-
final
- title → String
-
final
- width → double
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< HeaderCell> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited