TableWidget class

Main table widget - public entry point for the library This is a pure render widget that displays data from TableController

Inheritance

Constructors

TableWidget({Key? key, required TableController controller, bool isDarkMode = false, void onDrillDown(Map<String, dynamic> rowData, String field)?, void onSelectionChanged(List<Map<String, dynamic>> selectedRows)?, Map<String, Map<String, dynamic>>? highlightMetadata, List<Map<String, dynamic>>? multiCellSelections, Future<void> onRefresh()?})
const

Properties

controller TableController
final
hashCode int
The hash code for this object.
no setterinherited
highlightMetadata Map<String, Map<String, dynamic>>?
final
isDarkMode bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
multiCellSelections List<Map<String, dynamic>>?
final
onDrillDown → void Function(Map<String, dynamic> rowData, String field)?
final
onRefresh Future<void> Function()?
Optional pull-to-refresh callback. When provided, enables pull-to-refresh on the table. A centered loading indicator will appear while refreshing.
final
onSelectionChanged → void Function(List<Map<String, dynamic>> selectedRows)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<TableWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited