HorizontalTableAdapter class
Adapter that wraps horizontal_data_table package Isolates the package dependency and handles column splitting for frozen columns
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- HorizontalTableAdapter
Constructors
-
HorizontalTableAdapter({Key? key, required List<
Widget> headerWidgets, required List<Widget> rowBuilder(BuildContext context, int rowIndex), required List<double> columnWidths, int frozenColumnCount = 0, required int rowCount, void onScrollControllersReady(ScrollController vertical, ScrollController horizontal)?, Color? leftSideBackgroundColor, Color? rightSideBackgroundColor, Color? headerBackgroundColor, double headerHeight = 56.0, double itemHeight = 52.0}) -
const
Properties
-
columnWidths
→ List<
double> -
All column widths (will be split by adapter)
final
- frozenColumnCount → int
-
Number of frozen columns (first N columns stay fixed)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerBackgroundColor → Color?
-
final
- headerHeight → double
-
Header height
final
-
headerWidgets
→ List<
Widget> -
All header widgets (pre-built, will be split by adapter)
final
- itemHeight → double
-
Row height
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- leftSideBackgroundColor → Color?
-
Colors
final
- onScrollControllersReady → void Function(ScrollController vertical, ScrollController horizontal)?
-
Callback when scroll controllers are ready
final
- rightSideBackgroundColor → Color?
-
final
-
rowBuilder
→ List<
Widget> Function(BuildContext context, int rowIndex) -
Builder for row cells - returns all cell widgets for a row
final
- rowCount → int
-
Total number of rows
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited