config/cell_highlight_config library
Classes
- CellBorders
- Border sides that need thick highlighting for group edges Used to determine which borders of a cell should be emphasized
- CellHighlightConfig
- Configuration for cell highlighting (collaborative editing style) Used to highlight cells with colored borders when multiple users are editing