CellHighlightConfig class
Configuration for cell highlighting (collaborative editing style) Used to highlight cells with colored borders when multiple users are editing
Constructors
- CellHighlightConfig({bool enabled = false, Color? color, String? userId, String? userName})
-
const
-
CellHighlightConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited