ConditionalFormatting class
Conditional formatting configuration (cell colors based on value)
- Annotations
Constructors
- ConditionalFormatting({required int order, required String type, required String style, FormattingBasedOn? basedOn})
-
const
-
ConditionalFormatting.fromJson(Map<
String, dynamic> json) -
factory
Properties
- affectsBackground → bool
-
no setter
- affectsText → bool
-
no setter
- basedOn → FormattingBasedOn?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEnabled → bool
-
no setter
- isGradient → bool
-
no setter
- isSolid → bool
-
no setter
- order → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → String
-
final
- type → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited