SolidFormatting class
Solid color formatting (threshold-based)
- Annotations
Constructors
-
SolidFormatting({required double lowerThreshold, required double higherThreshold, required String lower, required String mid, required String higher, String? color, List<
SolidFormattingSet> ? sets}) -
const
-
SolidFormatting.fromJson(Map<
String, dynamic> json) -
factory
Properties
- color → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasSets → bool
-
Whether this uses multi-range sets instead of simple thresholds
no setter
- higher → String
-
final
- higherThreshold → double
-
final
- lower → String
-
final
- lowerThreshold → double
-
final
- mid → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sets
→ List<
SolidFormattingSet> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited