TableConfig class
Main table configuration Maps from visualResponse JSON to internal table structure
- Annotations
Constructors
-
TableConfig({required String visualType, required String visualName, required String title, required String query, List<
ColumnConfig> rowIndex = const [], List<ColumnConfig> valuesConfig = const [], required List<ColumnConfig> columns, int fixedColumns = 0, bool totals = false, bool topN = false, String? sortColumn, String? sortOrder, bool dataTreeStartExpanded = false, bool treeEnabled = false, bool headerFilter = false, bool selectableRows = false, bool showSelectionChips = true}) -
const
-
TableConfig.fromJson(Map<
String, dynamic> json) -
Parse from visualResponse JSON
factory
Properties
-
allColumns
→ List<
ColumnConfig> -
Get all columns including rowIndex
no setter
-
columns
→ List<
ColumnConfig> -
final
- dataTreeStartExpanded → bool
-
final
- fixedColumns → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerFilter → bool
-
final
- initialSortAscending → bool
-
Get initial sort ascending flag
no setter
- isMatrix → bool
-
Check if this is a matrix-type table
no setter
- query → String
-
final
-
rowIndex
→ List<
ColumnConfig> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectableRows → bool
-
final
- showSelectionChips → bool
-
final
- sortColumn → String?
-
final
- sortOrder → String?
-
final
- title → String
-
final
- topN → bool
-
final
- totals → bool
-
final
- treeEnabled → bool
-
final
-
valuesConfig
→ List<
ColumnConfig> -
final
- visualName → String
-
final
- visualType → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited