TableState class
Immutable state object for the table This is the single source of truth for all table data and UI state
- Annotations
Constructors
-
TableState({required TableConfig config, required List<
ColumnConfig> columns, required List<ColumnConfig> fixedColumns, required List<ColumnConfig> dataColumns, required List<double> fixedColumnWidths, required List<double> dataColumnWidths, required List<ColumnGroup> columnGroups, required List<Map< originalRows, required List<String, dynamic> >Map< totalRows, required List<String, dynamic> >Map< regularRows, required List<String, dynamic> >Map< visibleRows, required int totalRowCount, String? sortField, bool sortAscending = true, Map<String, dynamic> >String, String> columnFilters = const {}, String? globalSearchQuery, Set<String> selectedRowIds = const {}, Map<String, Map< selectedRowsData = const {}, bool isTreeData = false, Set<String, dynamic> >String> expandedRowIds = const {}, List<TreeRow> treeRows = const [], bool allExpanded = false, required List<double> columnWidths, int loadedRowCount = 50, bool isLoadingMore = false}) -
const
Properties
-
allColumns
→ List<
ColumnConfig> -
Get all columns (fixed + data) - for backward compatibility
no setter
-
allColumnWidths
→ List<
double> -
Get all column widths - for backward compatibility
no setter
- allExpanded → bool
-
final
-
columnFilters
→ Map<
String, String> -
final
-
columnGroups
→ List<
ColumnGroup> -
final
-
columns
→ List<
ColumnConfig> -
final
-
columnWidths
→ List<
double> -
final
- config → TableConfig
-
final
-
dataColumns
→ List<
ColumnConfig> -
final
- dataColumnsWidth → double
-
Get total width of data columns
no setter
-
dataColumnWidths
→ List<
double> -
final
-
expandedRowIds
→ Set<
String> -
final
-
fixedColumns
→ List<
ColumnConfig> -
final
- fixedColumnsWidth → double
-
Get total width of fixed columns
no setter
-
fixedColumnWidths
→ List<
double> -
final
- globalSearchQuery → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasSelection → bool
-
Check if any rows are selected
no setter
- isLoadingMore → bool
-
final
- isTreeData → bool
-
final
- loadedRowCount → int
-
final
-
originalRows
→ List<
Map< String, dynamic> > -
final
-
regularRows
→ List<
Map< String, dynamic> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectedRowIds
→ Set<
String> -
final
-
selectedRowsData
→ Map<
String, Map< String, dynamic> > -
final
- sortAscending → bool
-
final
- sortField → String?
-
final
- totalColumnsWidth → double
-
Get total width of all columns
no setter
- totalRowCount → int
-
final
-
totalRows
→ List<
Map< String, dynamic> > -
final
-
treeRows
→ List<
TreeRow> -
final
- visibleRowCount → int
-
Get visible row count (respects progressive loading)
no setter
-
visibleRows
→ List<
Map< String, dynamic> > -
final
Methods
-
copyWith(
{TableConfig? config, List< ColumnConfig> ? columns, List<ColumnConfig> ? fixedColumns, List<ColumnConfig> ? dataColumns, List<double> ? fixedColumnWidths, List<double> ? dataColumnWidths, List<ColumnGroup> ? columnGroups, List<Map< ? originalRows, List<String, dynamic> >Map< ? totalRows, List<String, dynamic> >Map< ? regularRows, List<String, dynamic> >Map< ? visibleRows, int? totalRowCount, String? sortField, bool? sortAscending, Map<String, dynamic> >String, String> ? columnFilters, String? globalSearchQuery, Set<String> ? selectedRowIds, Map<String, Map< ? selectedRowsData, bool? isTreeData, Set<String, dynamic> >String> ? expandedRowIds, List<TreeRow> ? treeRows, bool? allExpanded, List<double> ? columnWidths, int? loadedRowCount, bool? isLoadingMore}) → TableState - Create a copy with updated values
-
findGroupForColumn(
int columnIndex, bool isFixed) → ColumnGroup? - Find column group containing a column at given index in a section
-
isRowExpanded(
String rowId) → bool - Check if row is expanded (for tree data)
-
isRowSelected(
String rowId) → bool - Check if row is selected
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited