ConditionalFormatter class
Manages conditional formatting (cell colors based on values) Extracts color calculation logic from UI widgets
Constructors
- ConditionalFormatter({required ConditionalFormatting config, bool isDarkMode = false})
-
const
Properties
- config → ConditionalFormatting
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDarkMode → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getColors(
{required Map< String, dynamic> rowData, required Color defaultBgColor, required Color defaultTextColor}) → CellColors - Get cell colors based on row data Returns background and text colors
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited