HighlightManager class

Manages cell highlighting and group border detection Detects groups of adjacent cells with same highlight color and calculates which borders should be thick (group edges only)

Constructors

HighlightManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

calculateGroupBorders(List<Map<String, dynamic>> rows, List<ColumnConfig> columns, Map<String, Map<String, dynamic>> highlightMetadata) Map<String, CellBorders>
Calculate which borders should be thick for each highlighted cell Returns Map<cellKey, CellBorders> where cellKey = 'rowId_columnField'